"use client";

import React, { useState } from "react";
import Link from "next/link";
import Button from "@/snippets/button/button";

const Navbar = () => {
  const [isOpen, setIsOpen] = useState(false);

  const toggleMenu = () => {
    setIsOpen(!isOpen);
  };

  return (
    <header className="flex justify-between items-center px-10 py-6 font-clashDisplay">
      {/* Humanity Aid text */}
      <Link href="/">
        <div className="text-2xl text-blueaid font-extrabold">Humanity Aid</div>
      </Link>

      {/* Hamburger Menu for smaller screens */}
      <div className="block lg:hidden">
        <button
          onClick={toggleMenu}
          className="text-textaid-200 focus:outline-none"
        >
          <svg
            className="h-8 w-8 fill-current"
            xmlns="http://www.w3.org/2000/svg"
            viewBox="0 0 24 24"
          >
            {isOpen ? (
              <path
                fillRule="evenodd"
                clipRule="evenodd"
                d="M19 12a1 1 0 0 1-1 1H6a1 1 0 1 1 0-2h12a1 1 0 0 1 1 1zm-1-5a1 1 0 0 1 1-1H6a1 1 0 1 1 0-2h12a1 1 0 0 1 1 1zm0 10a1 1 0 0 1-1 1H6a1 1 0 0 1 0-2h12a1 1 0 0 1 1 1z"
              />
            ) : (
              <path
                fillRule="evenodd"
                clipRule="evenodd"
                d="M4 6a1 1 0 0 1 1-1h14a1 1 0 1 1 0 2H5a1 1 0 0 1-1-1zm0 5a1 1 0 0 1 1-1h14a1 1 0 1 1 0 2H5a1 1 0 0 1-1-1zm0 5a1 1 0 0 1 1-1h14a1 1 0 1 1 0 2H5a1 1 0 0 1-1-1z"
              />
            )}
          </svg>
        </button>
      </div>

      {/* Navigation links */}
      <nav
        className={`lg:flex lg:items-center lg:w-auto ${
          isOpen ? "block" : "hidden"
        }`}
      >
        <div className="flex flex-col lg:flex-row lg:items-center lg:gap-6">
          <Link href="/">
            <div className="text-textaid-200 text-lg font-medium hover:text-blueaid transition duration-300">
              Home
            </div>
          </Link>
          <Link href="/signup">
            <div className="text-textaid-200 text-lg font-medium hover:text-blueaid transition duration-300">
              Get Help
            </div>
          </Link>
          <Link href="/signup">
            <div className="text-textaid-200 text-lg font-medium hover:text-blueaid transition duration-300">
              Offer Help
            </div>
          </Link>
        </div>
      </nav>

      {/* Authentication buttons */}
      <div className="flex justify-center items-center gap-5">
        {/* <Link href="/login">
          <div className="text-blueaid text-lg font-medium bg-white px-4 py-2 border-2 border-blueaid rounded-md hover:bg-blueaid hover:text-white transition duration-300">
            Login
          </div>
        </Link> */}
        <Link href="/login">
          <Button variant="secondary" animation="rotate" text="Login" />
        </Link>
        <Link href="/signup">
          <Button text="Sign up" animation="rotate" />
        </Link>

        {/* <Link href="/signup">
          <div className="bg-blueaid text-lg font-medium text-white px-4 py-2 rounded-md hover:bg-blue-600 transition duration-300">
            Sign Up
          </div>
        </Link> */}
      </div>
    </header>
  );
};

export default Navbar;
